==> ejc-bfyjerp-impl-3.0.0-20250221.032831-134-sources.jar: com/ejianc/business/oa/bean/CertTypeEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人力行政-证照分类档案
 * 
 * @author generator
 * 
 */
 @TableName("ejc_oa_cert_type")
public class CertTypeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 创建人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改人
    @TableField(value="parent_id")
    private Long parentId; // 父ID
    @TableField(value="parent_code")
    private String parentCode; // 父分类编号
    @TableField(value="parent_name")
    private String parentName; // 父分类名称
    @TableField(value="code_plan")
    private String codePlan; // 编码方案
    @TableField(value="inner_code")
    private String innerCode; // 证照类别树内码
    @TableField(value="code")
    private String code; // 证照类别分类编号
    @TableField(value="name")
    private String name; // 证照类别分类名称
    @TableField(value="description")
    private String description; // 描述
    @TableField(value="sequence")
    private Integer sequence; // 排序
    @TableField(value="leaf_flag")
    private Integer leafFlag; // 是否末级
    @TableField(value="enabled")
    private Integer enabled; // 1:启用/0:停用
    
    
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public String getParentCode() {
        return parentCode;
    }

    public void setParentCode(String parentCode) {
        this.parentCode = parentCode;
    }
    public String getParentName() {
        return parentName;
    }

    public void setParentName(String parentName) {
        this.parentName = parentName;
    }
    public String getCodePlan() {
        return codePlan;
    }

    public void setCodePlan(String codePlan) {
        this.codePlan = codePlan;
    }
    public String getInnerCode() {
        return innerCode;
    }

    public void setInnerCode(String innerCode) {
        this.innerCode = innerCode;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public Integer getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Integer leafFlag) {
        this.leafFlag = leafFlag;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20250618.104002-227-sources.jar: com/ejianc/business/oa/bean/CertTypeEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人力行政-证照分类档案
 * 
 * @author generator
 * 
 */
 @TableName("ejc_oa_cert_type")
public class CertTypeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 创建人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改人
    @TableField(value="parent_id")
    private Long parentId; // 父ID
    @TableField(value="parent_code")
    private String parentCode; // 父分类编号
    @TableField(value="parent_name")
    private String parentName; // 父分类名称
    @TableField(value="code_plan")
    private String codePlan; // 编码方案
    @TableField(value="inner_code")
    private String innerCode; // 证照类别树内码
    @TableField(value="code")
    private String code; // 证照类别分类编号
    @TableField(value="name")
    private String name; // 证照类别分类名称
    @TableField(value="description")
    private String description; // 描述
    @TableField(value="sequence")
    private Integer sequence; // 排序
    @TableField(value="leaf_flag")
    private Integer leafFlag; // 是否末级
    @TableField(value="enabled")
    private Integer enabled; // 1:启用/0:停用
    @TableField(exist=false)
    private Boolean isLeaf; // 是否是叶子节点

    @TableField(exist=false)
    private List<CertTypeEntity> children = new ArrayList<>();

    public Boolean getIsLeaf() {
        return isLeaf;
    }

    public void setIsLeaf(Boolean leaf) {
        isLeaf = leaf;
    }

    public List<CertTypeEntity> getChildren() {
        return children;
    }

    public void setChildren(List<CertTypeEntity> children) {
        this.children = children;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public String getParentCode() {
        return parentCode;
    }

    public void setParentCode(String parentCode) {
        this.parentCode = parentCode;
    }
    public String getParentName() {
        return parentName;
    }

    public void setParentName(String parentName) {
        this.parentName = parentName;
    }
    public String getCodePlan() {
        return codePlan;
    }

    public void setCodePlan(String codePlan) {
        this.codePlan = codePlan;
    }
    public String getInnerCode() {
        return innerCode;
    }

    public void setInnerCode(String innerCode) {
        this.innerCode = innerCode;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public Integer getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Integer leafFlag) {
        this.leafFlag = leafFlag;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    
}
